netapp_ontap.models.nvme_subsystem_controller_host API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_subsystem_controller_host`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeSubsystemControllerHostSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeSubsystemControllerHost object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `id: str GET`

    The host identifier registered with the controller.

    Example: b8546ca6097349e5b1558dc154fc073b

  `nqn: str GET`

    The NVMe qualified name of the host.

    Example: nqn.2014-08.org.nvmexpress:uuid:c2846cb1-89d2-4020-a3b0-71ce907b4eef

  `transport_address: str GET`

    The transport address of the host.

    Example: nn-0x20000090fae00806:pn-0x10000090fae00806